@@ -4,8 +4,9 @@ and then provided to other classes via composition, not inheritance.
 """
 from dataclasses import dataclass
 import ipywidgets as ipw
-from ipywidgets import HTML, IntProgress, VBox, HBox, Box, Layout, Button
+from ipywidgets import HTML, FloatProgress, VBox, HBox, Box, Layout, Button
 from . import styles
+from ..utils import html
 
 
 auto_layout =  Layout(width='auto')
@@ -18,47 +19,49 @@ class _Buttons:
     """
     Instantiate under `Widgets` class only.
     """
-    prev =  Button(icon='chevron-left',layout= Layout(width='auto',height='auto')).add_class('arrows')
-    next =  Button(icon='chevron-right',layout= Layout(width='auto',height='auto')).add_class('arrows')
+    prev    =  Button(icon='chevron-left',layout= Layout(width='auto',height='auto')).add_class('arrows')
+    next    =  Button(icon='chevron-right',layout= Layout(width='auto',height='auto')).add_class('arrows')
     setting =  Button(description= '\u2630',layout= Layout(width='auto',height='auto')).add_class('menu').add_class('float-cross-btn')
     capture =  Button(icon='camera',layout= Layout(width='auto',height='auto'),
-                    tooltip='Take Screen short in full screen. Order of multiple shots in a slide is preserved!',
-            ).add_class('screenshot-btn') # .add_class('menu')
-    pdf = Button(description='Save PDF',layout= Layout(width='auto',height='auto'))
-    png = Button(description='Save PNG',layout= Layout(width='auto',height='auto'))
-    print = Button(description='Print PDF',layout= Layout(width='auto',height='auto'))
+                tooltip='Take Screen short in full screen. Order of multiple shots in a slide is preserved!',
+                ).add_class('screenshot-btn') # .add_class('menu')
+    pdf     = Button(description='Save PDF',layout= Layout(width='auto',height='auto'))
+    png     = Button(description='Save PNG',layout= Layout(width='auto',height='auto'))
+    print   = Button(description='Print PDF',layout= Layout(width='auto',height='auto'))
     
-
 @dataclass(frozen=True)
 class _Toggles:
     """
     Instantiate under `Widgets` class only.
     """
-    display =  ipw.ToggleButtons(description='Display Mode',options=[('Inline',0),('Sidebar',1)],value = 1).add_class('DisplaySwitch')
-    fscrn = ipw.ToggleButton(description='Window',icon='expand',value = False).add_class('sidecar-only').add_class('window-fs')
-    zoom = ipw.ToggleButton(description='Zoom Items',icon='toggle-off',value = False).add_class('sidecar-only').add_class('mpl-zoom')
-    timer = ipw.ToggleButton(description='Timer',icon='play',value = False).add_class('sidecar-only').add_class('presenter-btn')             
+    display = ipw.ToggleButtons(description='Display Mode',options=[('Inline',0),('Sidebar',1)],value = 1).add_class('DisplaySwitch')
+    fscrn   = ipw.ToggleButton(description='Window',icon='expand',value = False).add_class('sidecar-only').add_class('window-fs')
+    zoom    = ipw.ToggleButton(description='Zoom Items',icon='toggle-off',value = False).add_class('sidecar-only').add_class('mpl-zoom')
+    timer   = ipw.ToggleButton(description='Timer',icon='play',value = False).add_class('sidecar-only').add_class('presenter-btn')             
         
 
-
 @dataclass(frozen=True)
 class _Htmls:
     """
     Instantiate under `Widgets` class only.
     """
-    info    = HTML('<p>Put Your Info Here using `self.set_footer` function</p>')
-    theme   = HTML(styles.style_html(styles.theme_roots['Fancy'].replace(
-        '__text_size__','16px')).replace(
-        '__breakpoint_width__','650px').replace(
-        '__textfont__','sans-serif').replace(
-        '__codefont__','var(--jp-code-font-family)'))
-    main    = HTML(styles.main_layout_css)
-    sidebar = HTML(styles.sidebar_layout_css()) # Should be separate CSS
+    footer  = HTML('<p>Put Your Info Here using `self.set_footer` function</p>').add_class('Footer')
+    theme   = HTML(html('style',styles.style_html(styles.theme_roots['Fancy'].replace(
+                '__text_size__','16px')).replace(
+                '__breakpoint_width__','650px').replace(
+                '__textfont__','sans-serif').replace(
+                '__codefont__','var(--jp-code-font-family)')
+                ).value)
+    main    = HTML(html('style',styles.main_layout_css).value)
+    sidebar = HTML(html('style',styles.sidebar_layout_css()).value) # Should be separate CSS
     loading = HTML() #SVG Animation in it
-    logo    =  HTML()
+    logo    = HTML()
     toast   = HTML() # For notifications
     cursor  = HTML().add_class('LaserPointer') # For beautiful cursor
-    notes   = ipw.HTML('Notes Area').add_class('Inline-Notes') # For below slides area
+    notes   = HTML('Notes Area').add_class('Inline-Notes') # For below slides area
+    hilite  = HTML() # Updated in settings on creation. For code blocks.
+    fscrn   = HTML() # Full Screen CSS, do not add here!
+    zoom    = HTML() # zoom-container CSS, do not add here!
 
 @dataclass(frozen=True)
 class _Inputs:
@@ -83,11 +86,11 @@ class _Sliders:
     """
     Instantiate under `Widgets` class only.
     """
-    progress   = ipw.IntSlider(options= [(f'{i}',i) for i in range(1)],continuous_update=False,readout=True)
-    visible    = ipw.IntSlider(description='View (%)',min=0,value=100,max=100,orientation='vertical').add_class('float-control')
-    height     = ipw.IntSlider(**describe('Height (px)'),min=200,max=2160, value = 400,continuous_update=False).add_class('height-slider') #2160 for 4K screens
-    width      = ipw.IntSlider(**describe('Width (vw)'),min=20,max=100, value = 50,continuous_update=False).add_class('width-slider')
-    scale      = ipw.FloatSlider(**describe('Font Scale'),min=0.5,max=3,step=0.0625, value = 1.0,readout_format='5.3f',continuous_update=False)
+    progress = ipw.SelectionSlider(options=[('0',0)], value=0, continuous_update=False,readout=True)
+    visible  = ipw.IntSlider(description='View (%)',min=0,value=100,max=100,orientation='vertical').add_class('float-control')
+    height   = ipw.IntSlider(**describe('Height (px)'),min=200,max=2160, value = 400,continuous_update=False).add_class('height-slider') #2160 for 4K screens
+    width    = ipw.IntSlider(**describe('Width (vw)'),min=20,max=100, value = 50,continuous_update=False).add_class('width-slider')
+    scale    = ipw.FloatSlider(**describe('Font Scale'),min=0.5,max=3,step=0.0625, value = 1.0,readout_format='5.3f',continuous_update=False)
         
 
 @dataclass(frozen=True)
@@ -104,11 +107,11 @@ class _Outputs:
     """
     Instantiate under `Widgets` class only.
     """
-    slide  = ipw.Output(layout= Layout(width='auto',height='auto',margin='auto',overflow='auto',padding='2px 36px')
-                              ).add_class('SlideArea')
-    intro  = ipw.Output(clear_output=False, layout=Layout(width='100%',height='100%',overflow='auto',padding='4px')).add_class('panel-text')
-    js_fix = ipw.Output(layout=Layout(width='auto',height='0px'))
-    js_var = ipw.Output(layout=Layout(width='auto',height='0px'))
+    slide = ipw.Output(layout= Layout(height='auto',margin='auto',overflow='auto',padding='2px 36px') # do not set width here, in css
+            ).add_class('SlideArea')
+    intro = ipw.Output(clear_output=False, layout=Layout(width='100%',height='100%',overflow='auto',padding='4px')).add_class('panel-text')
+    fixed = ipw.Output(layout=Layout(width='auto',height='0px')) # For fixed javascript
+    renew = ipw.Output(layout=Layout(width='auto',height='0px')) # Content can be added dynamically
 
 
 def _custom_progressbar(intslider):
@@ -125,6 +128,9 @@ def _custom_progressbar(intslider):
     .NavWrapper .nav-box .menu:hover {
         opacity:1;
     }
+    .NavWrapper .nav-box .Footer p {
+        font-size:14px !important;
+    }
     .NavWrapper .nav-box {
         z-index:50;
         overflow: hidden;
@@ -132,7 +138,7 @@ def _custom_progressbar(intslider):
     .NavWrapper .widget-hprogress {
         height:4px; !impportant;
     }
-    .NavWrapper, .NavWrapper>div {
+    .NavWrapper, .NavWrapper > div {
         padding:0px;
         margin:0px;
         overflow:hidden;
@@ -152,9 +158,8 @@ def _custom_progressbar(intslider):
         transform:translate(-2px,1px) !important;
     }
     </style>''')
-    intprogress = IntProgress(min=intslider.min, max=intslider.max, layout=Layout(width='100%'))
-    for prop in ('min','max','value'):
-        ipw.link((intprogress, prop), (intslider, prop)) # These links enable auto refresh from outside
+    intprogress = FloatProgress(min=0, max=100,value=0, layout=Layout(width='100%'))
+    ipw.link((intslider, 'value'), (intprogress, 'value')) # This link enable auto refresh from outside
     
     return intprogress, html
 
@@ -194,7 +199,14 @@ class Widgets:
     """
     Instantiate under `LiveSLides` class only and provide to other classes after built-up.
     """
+    def __setattr__(self, name , value):
+        if name in self.__dict__:
+            raise AttributeError(f'{name} is a read-only attribute')
+        
+        self.__dict__[name] = value
+        
     def __init__(self):
+        # print(f'Inside: {self.__class__.__name__}')
         self.buttons = _Buttons()
         self.toggles = _Toggles()
         self.sliders = _Sliders()
@@ -216,27 +228,27 @@ class Widgets:
             self.buttons.next
         ]).add_class('controls') 
         
+        self.footerbox = HBox([
+            self.buttons.setting,
+            HBox([self.htmls.footer],layout= Layout(overflow_x = 'auto',overflow_y='hidden')) ,
+            self.buttons.capture
+        ],layout=Layout(height='32px')).add_class('nav-box')
+        
         self.navbox = VBox([
-            HBox([self.buttons.setting,
-                HBox([self.htmls.info],layout= Layout(overflow_x = 'auto',overflow_y='hidden')),
-                self.buttons.capture
-            ],layout=Layout(height='32px')
-            ).add_class('nav-box'),
+            self.footerbox,
             VBox([
                 self.__proghtml,
                 self.progressbar
                 ])
-        ]).add_class('NavWrapper')  #class is must
-        
-        
+        ]).add_class('NavWrapper')   #class is must
         
         self.panelbox = VBox([
             Box([
                 self.outputs.intro,
                 self.buttons.setting,
-            ],layout=Layout(width='100%',height='auto',overflow='hidden')),
-            self.outputs.js_fix, 
-            self.outputs.js_var, # Must be in middle so that others dont get disturbed.
+            ],layout=Layout(width='100%',height='auto',overflow='hidden')) ,
+            self.outputs.fixed, 
+            self.outputs.renew, # Must be in middle so that others dont get disturbed.
             VBox([
                 self.sliders.height.add_class('voila-sidecar-hidden'), 
                 self.sliders.width.add_class('voila-sidecar-hidden'),
@@ -248,19 +260,19 @@ class Widgets:
                     self.checks.notes, 
                     self.checks.toast, 
                     self.checks.reflow
-                ],layout=btns_layout),
+                ],layout=btns_layout) ,
                 self.ddowns.clear,
                 HBox([
                     self.buttons.png, 
                     self.buttons.pdf, 
                     self.buttons.print
-                ], layout=btns_layout),
+                ], layout=btns_layout) ,
                 HTML('<hr/>'),
                 HBox([
                     self.toggles.fscrn,
                     self.toggles.zoom, 
                     self.toggles.timer
-                ], layout=btns_layout),
+                ], layout=btns_layout) ,
             ],layout = Layout(width='100%',height='max-content',min_height='400px',overflow='auto'))
         ],layout = Layout(width='70%',min_width='50%',height='100%',padding='4px',overflow='auto',display='none')
         ).add_class('panel') 
@@ -277,7 +289,10 @@ class Widgets:
             self.htmls.logo, 
             self.htmls.sidebar,
             self.panelbox, 
-            self.htmls.cursor ,
+            self.htmls.cursor,
+            self.htmls.hilite,
+            self.htmls.zoom,
+            self.htmls.fscrn,
             HBox([ #Slide_box must be in a box to have animations work
                 self.slidebox , 
             ],layout= Layout(width='100%',max_width='100%',height='100%',overflow='hidden')), #should be hidden for animation purpose
