@@ -8,9 +8,10 @@ from IPython.display import display
 from IPython.utils.capture import capture_output
 import ipywidgets as ipw
 
+from .extended_md import ExetendedMarkdown
 from .source import Source
 from .writers import write, iwrite
-from .formatter import bokeh2html, plt2html
+from .formatter import bokeh2html, plt2html, highlight
 from . import utils
 
 _under_slides = {k:getattr(utils,k,None) for k in utils.__all__}
@@ -40,28 +41,28 @@ class _PrivateSlidesClass(BaseLiveSlides):
             
         self.plt2html   = plt2html
         self.bokeh2html = bokeh2html
+        self.highlight  = highlight
         self.source = Source # Code source
         self.write  = write # Write IPython objects in slides
         self.iwrite = iwrite # Write Widgets/IPython in slides
-        self.shell.register_magic_function(self.__slide, magic_kind='cell',magic_name='slide')
-        self.shell.register_magic_function(self.__title, magic_kind='cell',magic_name='title')
-        self.user_ns = self.shell.user_ns #important for set_dir
+        with suppress(Exception): # Avoid error when using setuptools to install
+            self.shell.register_magic_function(self.__slide, magic_kind='cell',magic_name='slide')
+            self.shell.register_magic_function(self.__title, magic_kind='cell',magic_name='title')
+            self.user_ns = self.shell.user_ns #important for set_dir
         
         self._citations = {} # Initialize citations
         self.__slides_mode = True # Default is slides mode since it is more intuitive
         self._computed_display = False # Do not load all slides by default
-        with capture_output() as cap:
-            write(how_to_slide)
         
-        self.__slides_dict = {'0': cap} # Initialize slide dictionary
+        self.__slides_dict = {} # Initialize slide dictionary, updated by user or by _on_displayed.
         self._slides_notes = {'0': None} # Initialize notes dictionary
         self._slides_css = {} # Initialize css dictionary for each slide
         self._current_slide = '0' # Initialize current slide for notes at title page
         self._i2f_dict = {'0':'0'} # input number -> display number of slide
         self._f2i_dict = {'0':'0'} # display number -> input number of slide
         
-        self.__iterable = self.__collect_slides() # Collect internally
-        self._nslides = int(self.__iterable[-1]['n']) if self.__iterable else 0 # Real number of slides
+        self.__iterable = [] #self.__collect_slides() # Collect internally
+        self._nslides =  0 # Real number of slides
         self._max_index = 0 # Maximum index including frames
         
         self.loading_html = self.widgets.htmls.loading #SVG Animation in it
@@ -71,8 +72,7 @@ class _PrivateSlidesClass(BaseLiveSlides):
         
         # All Box of Slides
         self._box =  self.widgets.mainbox
-        self._box.on_displayed(lambda change: self.__muti_notebook_slides_alert()) 
-        self.__update_content(True) # First attmpt will only update title page
+        self._box.on_displayed(self._on_displayed) 
         self._display_box_ = ipw.VBox() # Initialize display box
     
     def _check_computed(self, what_cannot_do):
@@ -81,10 +81,22 @@ class _PrivateSlidesClass(BaseLiveSlides):
             'Use `.pre_compute_display(False)` to disable it and then {act}. '
             'You may enable it after that for fast loading of slides while presenting!').format(act = what_cannot_do))
     
-    def __muti_notebook_slides_alert(self):
-        " Alert for multiple slides in other notebooks, as they don't work well together."
+    def _on_displayed(self, change):
         with self.widgets.outputs.renew:
             display(multi_slides_alert)
+        
+        self._make_sure_title() # Should be before showing it below
+        
+        self.widgets.slidebox.children[0].clear_output(wait=True)
+        with self.widgets.slidebox.children[0]: # title slide in both simple and computed case
+            self.__slides_dict['0'].show() # Instead of refreshing, we can just update the content of the title slides to avoid errors
+    
+    def _make_sure_title(self):
+        if '0' not in self.__slides_dict:
+            with capture_output() as captured:
+                write(how_to_slide)
+                
+            self.__slides_dict['0'] = captured
 
     @property
     def slides(self):
@@ -104,9 +116,10 @@ class _PrivateSlidesClass(BaseLiveSlides):
     def clear(self):
         "Clear all slides."
         self._check_computed('clear slides')
-        self.__slides_dict = {k:v for k,v in self.__slides_dict.items() if k == '0'} # keep title page
-        self._slides_notes = {k:v for k,v in self._slides_notes.items() if k == '0'} # keep title page's notes
-        self._toasts = {k:v for k,v in self._toasts.items() if k == '0' } # keep title page's toasts
+        self._make_sure_title() # Make sure title is there, before updating slides
+        self.__slides_dict = {'0':self.__slides_dict.get('0')} # keep title page
+        self._slides_notes = {'0':self._slides_notes.get('0',None)} # keep title page's notes
+        self._toasts = {'0':self._toasts.get('0',None) } # keep title page's toasts
         self.refresh() # Clear interface too
     
     def cite(self,key, citation,here=False):
@@ -302,20 +315,24 @@ class _PrivateSlidesClass(BaseLiveSlides):
             %%markdown
             Everything here and below is treated as markdown, not python code.
         """
-        line = line.strip() #VSCode bug to inclue \r in line
-        if line and not line.isnumeric():
-            raise ValueError(f'You should use %%slide integer, not %%slide {line}')
+        line = line.strip().split() #VSCode bug to inclue \r in line
+        if line and not line[0].isnumeric():
+            raise ValueError(f'You should use %%slide integer >= 1 -m(optional), got {line}')
         
-        with self.slide(int(line)):
-            self.shell.run_cell(cell)
+        with self.slide(int(line[0])):
+            if '-m' in line[1:]:
+                ExetendedMarkdown().parse(cell, display_inline = True)
+            else:
+                self.shell.run_cell(cell)
     
     @contextmanager
     def slide(self,slide_number,**css_props):
         """Use this context manager to generate any number of slides from a cell
         `css_props` are applied to current slide. `-` -> `_` as `font-size` -> `font_size` in python."""
-        if not ((isinstance(slide_number, int) and (slide_number >= 1)) or (slide_number == '0')): # '0' is title slide
-            raise ValueError(f'slide_number should be >= 1, got {slide_number}')
+        if not isinstance(slide_number, int):
+            raise ValueError(f'slide_number should be int >= 1, got {slide_number}')
         
+        assert slide_number >= 0 # slides should be >= 1, zero for title slide
         if self._computed_display and self.__slides_mode:
             yield # To avoid generator yied error
             self._check_computed('add slide')
@@ -335,14 +352,17 @@ class _PrivateSlidesClass(BaseLiveSlides):
     
     def __title(self,line,cell):
         "Turns to cell magic `title` to capture title"
-        with self.slide('0'):
-            self.shell.run_cell(cell)
+        with self.slide(0):
+            if '-m' in line:
+                ExetendedMarkdown().parse(cell, display_inline = True)
+            else:
+                self.shell.run_cell(cell)
             
     @contextmanager
     def title(self,**css_props):
         """Use this context manager to write title.
         `css_props` are applied to current slide. `-` -> `_` as `font-size` -> `font_size` in python."""
-        with self.slide('0', **css_props):
+        with self.slide(0, **css_props):
             yield
     
     def frames(self, slide_number, *objs, repeat = False, frame_height = 'auto', **css_props):
@@ -376,6 +396,7 @@ class _PrivateSlidesClass(BaseLiveSlides):
             if not isinstance(slide_number,int):
                 return print(f'slide_number expects integer, got {slide_number!r}')
             
+            assert slide_number >= 1 # Should be >= 1, should not add title slide as frames
             self._current_slide = f'{slide_number}.1' # First frame
 
             if not self.__slides_mode:
